refactor-nrepl.artifacts


artifact-listclj

(artifact-list {:keys [force]})
source

artifact-versionsclj

(artifact-versions {:keys [artifact]})

Returns a sorted list of artifact version strings. The list can either come from the artifacts cache, the maven search api or the clojars search api in that order.

Returns a sorted list of artifact version strings. The list can either come
from the artifacts cache, the maven search api or the clojars search api in
that order.
sourceraw docstring

artifactsclj

source

artifacts-fileclj

source

get-clojars-versions!clj

(get-clojars-versions! artifact)

Fetches all the versions of particular artifact from Clojars.

Fetches all the versions of particular artifact from Clojars.
sourceraw docstring

get-last-modified-from-fileclj

(get-last-modified-from-file file)

Returns last modified time in milliseconds or nil if file does not exist.

Returns last modified time in milliseconds or nil if file does not exist.
sourceraw docstring

hotload-dependencyclj

(hotload-dependency {:keys [coordinates]})

Add a Maven dependency to the running classpath.

:coordinates is a Leiningen-style vector string "[group/artifact \"version\"]" or a deps.edn-style map literal string. Returns the input string on success.

Add a Maven dependency to the running classpath.

`:coordinates` is a Leiningen-style vector string `"[group/artifact \"version\"]"`
or a deps.edn-style map literal string. Returns the input string on success.
sourceraw docstring

millis-per-dayclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries