refactor-nrepl.ns.libspec-allowlist


libspec-allowlistclj

(libspec-allowlist current-ns)

Obtains a libspec allowlist, which is the result of merging clj-refactor's own :libspec-whitelist with clj-kondo's :unused-namespace config.

Uses a memoized version if available.

Obtains a libspec allowlist, which is the result of merging clj-refactor's own `:libspec-whitelist`
with clj-kondo's `:unused-namespace` config.

Uses a memoized version if available.
sourceraw docstring

maybe-unwrap-quoteclj

(maybe-unwrap-quote obj)
source

with-memoized-libspec-allowlistcljmacro

(with-memoized-libspec-allowlist & body)

Memoizes the libspec-allowlist internals while body is executing.

Temporary memoization is important because:

  • one does want to reload clj-kondo config if the user changes it, without needing a JVM restart;
  • one doesn't want that to imply a performance hit in terms of repeatedly reading clj-kondo config files.
Memoizes the libspec-allowlist internals while `body` is executing.

_Temporary_ memoization is important because:

* one does want to reload clj-kondo config if the user changes it, without needing a JVM restart;
* one doesn't want that to imply a performance hit in terms of repeatedly reading clj-kondo config files.
sourceraw docstring

with-memoized-libspec-allowlist*clj

(with-memoized-libspec-allowlist* f)
source

cljdoc builds & hosts documentation for Clojure/Script libraries