refactor-nrepl.ns.pprint


pprintclj

(pprint x)

Pretty-prints x with custom, configurable overrides over clojure.pprint's settings.

This way, we try to generate a formatting that is agnostic / decoupled from clojure.pprint, and therefore that other tools can also consistently achieve.

Pretty-prints `x` with custom, configurable overrides over `clojure.pprint`'s settings.

This way, we try to generate a formatting that is agnostic / decoupled from clojure.pprint,
and therefore that other tools can also consistently achieve.
sourceraw docstring

pprint-metaclj

(pprint-meta m & {:keys [newlines] :or {newlines false}})

Given some metadata m, print the shorthand metadata first, and the longhand metadata second, trying to convert to shorthand notation if possible

If newlines is true, it prints a newline after each piece of longhand metadata

Given some metadata m, print the shorthand metadata first, and the
longhand metadata second, trying to convert to shorthand notation if
possible

If newlines is true, it prints a newline after each piece of
longhand metadata
sourceraw docstring

pprint-nsclj

(pprint-ns [_ name & more :as ns-form])
source

pprint-require-formclj

(pprint-require-form [_ & libspecs])
source

cljdoc builds & hosts documentation for Clojure/Script libraries