(artifact-versions {:keys [artifact]})Returns a sorted list of artifact version strings. The list can either come from the artifacts cache, the maven search api or the clojars search api in that order.
Returns a sorted list of artifact version strings. The list can either come from the artifacts cache, the maven search api or the clojars search api in that order.
(get-clojars-versions! artifact)Fetches all the versions of particular artifact from Clojars.
Fetches all the versions of particular artifact from Clojars.
(get-last-modified-from-file file)Returns last modified time in milliseconds or nil if file does not exist.
Returns last modified time in milliseconds or nil if file does not exist.
(hotload-dependency {:keys [coordinates]})Add a Maven dependency to the running classpath.
:coordinates is a Leiningen-style vector string "[group/artifact \"version\"]"
or a deps.edn-style map literal string. Returns the input string on success.
Add a Maven dependency to the running classpath. `:coordinates` is a Leiningen-style vector string `"[group/artifact \"version\"]"` or a deps.edn-style map literal string. Returns the input string on success.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |