(libspec-allowlist current-ns)Obtains a libspec allowlist, which is the result of merging clj-refactor's own :libspec-whitelist
with clj-kondo's :unused-namespace config.
Uses a memoized version if available.
Obtains a libspec allowlist, which is the result of merging clj-refactor's own `:libspec-whitelist` with clj-kondo's `:unused-namespace` config. Uses a memoized version if available.
(with-memoized-libspec-allowlist & body)Memoizes the libspec-allowlist internals while body is executing.
Temporary memoization is important because:
Memoizes the libspec-allowlist internals while `body` is executing. _Temporary_ memoization is important because: * one does want to reload clj-kondo config if the user changes it, without needing a JVM restart; * one doesn't want that to imply a performance hit in terms of repeatedly reading clj-kondo config files.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |